"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
// @ts-ignore
const ecc = require("eosjs-ecc");
// @ts-ignore
const cppModule = require("../build/Release/node_eos_signature_provider");
const eosjs_numeric_1 = require("eosjs/dist/eosjs-numeric");
class NodeEosjsSignatureProvider {
    constructor(privateKeys) {
        this.keys = new Map();
        if (privateKeys.length === 0)
            throw new Error("At least one private key must be specified");
        this.privateKeys = privateKeys;
    }
    getAvailableKeys() {
        return this.generateKeyPairs().then(() => Array.from(this.keys.keys()));
    }
    sign({ chainId, requiredKeys, serializedTransaction }) {
        return this.generateKeyPairs()
            .then(() => new Promise(resolve => {
            let privateKeys = requiredKeys
                .map(key => this.keys.get(key))
                .filter(pkey => pkey);
            const signBuf = Buffer.concat([
                Buffer.from(chainId, 'hex'),
                Buffer.from(serializedTransaction),
                Buffer.from(new Uint8Array(32)),
            ]);
            resolve({
                serializedTransaction: serializedTransaction,
                signatures: cppModule.sign(privateKeys, signBuf)
            });
        }));
    }
    generateKeyPairs() {
        if (this.keys.size !== 0)
            return Promise.resolve();
        return Promise.all(this.privateKeys.map(privateKey => {
            this.keys.set(eosjs_numeric_1.convertLegacyPublicKey(ecc.PrivateKey.fromString(privateKey).toPublic().toString()), privateKey);
        }));
    }
}
exports.default = NodeEosjsSignatureProvider;
//# sourceMappingURL=index.js.map